using System.Collections;
using System.Collections.Generic;
using DefaultNamespace;
using DefaultNamespace.Story;
using TMPro;
using Unity.VisualScripting;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.Serialization;

public class GameManager : MonoBehaviour
{
    [SerializeField] private GameObject menu;
    
    [SerializeField] private GameState gameState;

    private ButtonManager _buttonManager;

    private Choice _nextChoice;
    private Choice _currentChoice;
    private Choice.DisplayLayout _previousLayout;
    private GameStory _story;
    private GameLogic _logic;
    public TextMeshProUGUI _gold;
    
    [SerializeField] private TextMeshProUGUI storyText;

    [SerializeField] private TextMeshProUGUI choiceAText; 
    [SerializeField] private TextMeshProUGUI choiceBText; 
    [SerializeField] private TextMeshProUGUI choiceCText;
    [SerializeField] public Button choiceAButton;
    [SerializeField] public Button choiceBButton;
    [SerializeField] public Button choiceCButton;
    [SerializeField] private List<GameObject> preBackgrounds;

    private Dictionary<BackgroundImage, GameObject> _backgrounds;

    // Start is called before the first frame update
    void Start()
    {
        this._logic = new GameLogic(this);
        this._story = new GameStory(_logic);
        this.gameState = GameState.ENTRANCE;
        this._nextChoice = this._story.DisplayState(this.gameState);
        this._previousLayout = Choice.DisplayLayout.THREE;
        this._buttonManager = new ButtonManager(choiceAButton, choiceBButton, choiceCButton, this);
        this._backgrounds = new Dictionary<BackgroundImage, GameObject>();

        for (var i = 0; i < preBackgrounds.Count; i++)
        {
            var type = (BackgroundImage)i; 
            _backgrounds.Add(type, preBackgrounds[i]);
            preBackgrounds[i].SetActive(false);
        }
        _logic.SetImage(BackgroundImage.CAVE_ENTRANCE);
    }
    
    // Update is called once per frame
    void Update()
    {
        if (_nextChoice != null && _nextChoice != _currentChoice)
        {
            renderChoice(_nextChoice);
            this._currentChoice = this._nextChoice;
            this._nextChoice = null;
        }       
        _gold.text = $"Gold Counter: {_logic.GoldCounter}";
    }

    public void HandleButtonPress(ButtonManager.ButtonID buttonId)
    {
        var choice = _logic.SelectChoice(buttonId);
        renderChoice(choice);
    }

    private void renderChoice(Choice choice)
    {
        this.storyText.text = choice.GetStoryText();
        
        switch (choice.GetLayout())
        {
            case Choice.DisplayLayout.ONE: 
                choiceAText.GameObject().SetActive(true);
                choiceAText.text = choice.GetOptions()[0];
                choiceAButton.GameObject().SetActive(true);
                choiceBText.GameObject().SetActive(false);
                choiceBButton.GameObject().SetActive(false);
                choiceCText.GameObject().SetActive(false);
                choiceCButton.GameObject().SetActive(false);

                _previousLayout = Choice.DisplayLayout.ONE;
                break;
            
            case Choice.DisplayLayout.TWO:
                choiceAText.GameObject().SetActive(true);
                choiceAText.text = choice.GetOptions()[0];
                choiceAButton.GameObject().SetActive(true);
                choiceBText.GameObject().SetActive(true);
                choiceBText.text = choice.GetOptions()[1];
                choiceBButton.GameObject().SetActive(true);
                choiceCText.GameObject().SetActive(false);
                choiceCButton.GameObject().SetActive(false);

                //if (_previousLayout == Choice.DisplayLayout.THREE)
                //{
                //    choiceAText.GameObject().transform.position += new Vector3(175, 0, 0);
                //    choiceCText.GameObject().transform.position += new Vector3(-175, 0, 0);
                //}

                _previousLayout = Choice.DisplayLayout.TWO;
                
                break;
            
            case Choice.DisplayLayout.THREE: 
                choiceAText.GameObject().SetActive(true);
                choiceAText.text = choice.GetOptions()[0];
                choiceAButton.GameObject().SetActive(true);
                choiceBText.GameObject().SetActive(true);
                choiceBText.text = choice.GetOptions()[1];
                choiceBButton.GameObject().SetActive(true);
                choiceCText.GameObject().SetActive(true);
                choiceCText.text = choice.GetOptions()[2];
                choiceCButton.GameObject().SetActive(true);

                //if (_previousLayout == Choice.DisplayLayout.TWO)
                //{
                //    choiceAText.GameObject().transform.position += new Vector3(-175, 0, 0);
                //    choiceCText.GameObject().transform.position += new Vector3(175, 0, 0);
                //}

                _previousLayout = Choice.DisplayLayout.THREE;
                
                break;
        }
    }

    public GameState GetCurrentGameState()
    {
        return gameState;
    }

    public void SetCurrentGameState(GameState nextGameState)
    {
        gameState = nextGameState;
        _logic.ImageSelector();
    }
    
    public void SetNextChoice(Choice choice)
    {
        _nextChoice = choice;
    }

    public GameStory GetGameStory()
    {
        return _story;
    }

    public void SetBackgroundImage(BackgroundImage image)
    {
        foreach (var keyValuePair in _backgrounds)
        {
            keyValuePair.Value.SetActive(false);
        }
        _backgrounds[image].SetActive(true);
    }
}
