using System.Collections;
using System.Collections.Generic;
using UnityEditor;
using UnityEngine;
using TMPro;
using UnityEngine.SceneManagement;

namespace DefaultNamespace.Story
{
    public class GameLogic
    {
        private GameManager _manager;

        public GameLogic(GameManager manager)
        {
            _manager = manager;
        }

        public int DrunkCounter = 0;
        public int Drinks2 = 0;
        public int GoldCounter = 0;
        public bool GoldJungle = false;
        public bool GoldWaterfall = false;
        public bool GoldInsect = false;
        public bool HasEquipment = false;
        public bool HasFixedEquipment = false;
        public bool HasDynamite = false;
        public bool VisitedBlockedPath;

        void  Update() 
        {

        }

        public Choice SelectChoice(ButtonManager.ButtonID buttonID) // put button number as parameter
        {
            // nextChoice = currentChoice;
            switch (_manager.GetCurrentGameState())
            {
                case GameState.ENTRANCE:
                    return HandleEntrance(buttonID);
                case GameState.ENTRANCEAGAIN:
                    return HandleEntranceAgain(buttonID);
                case GameState.ENTRANCEBROKEN:
                    return HandleEntranceBroken(buttonID);
                case GameState.ENTRANCEFIXED:
                    return HandleEntranceFixed(buttonID);
                case GameState.ENTRANCETRY:
                    return HandleEntranceTry(buttonID);
                case GameState.LOCKER:
                    return HandleLocker(buttonID);
                case GameState.LOCKERGETEQUIP:
                    return HandleLockerGetEquip(buttonID);
                case GameState.LOCKERHASEQUIP:
                    return HandleLockerHasEquip(buttonID);
                case GameState.SMITH:
                    return HandleSmith(buttonID);
                case GameState.SMITHFIXED:
                    return HandleSmithFixed(buttonID);
                case GameState.SMITHHASFIXED:
                    return HandleSmithHasFixed(buttonID);
                case GameState.SMITHNOEQUIP:
                    return HandleSmithNoEquip(buttonID);
                case GameState.SMITHTALK:
                    return HandleSmithTalk(buttonID);
                case GameState.MINES:
                    return HandleMines(buttonID);
                case GameState.ABANDONED_LAIR:
                    return HandleAbandonedLair(buttonID);
                case GameState.ABANDONED_LAIRNOSEARCH:
                    return HandleAbandonedLairNoSearch(buttonID);
                case GameState.ABANDONED_LAIRSEARCHFIND:
                    return HandleAbandonedLairSearchFind(buttonID);
                case GameState.ABANDONED_LAIRTNT:
                    return HandleAbandonedLairTNT(buttonID);
                case GameState.BLOCKED_PATH:
                    return HandleBlockedPath(buttonID);
                case GameState.BLOCKED_PATHUSETNT:
                    return HandleBlockedPathUseTNT(buttonID);
                case GameState.BLOCKED_PATHTNT:
                    return HandleBlockedPathTNT(buttonID);
                case GameState.JUNGLE:
                    return HandleJungle(buttonID);
                case GameState.JUNGLEGOLD:
                    return HandleJungleGold(buttonID);
                case GameState.JUNGLEAFTERGOLD:
                    return HandleJungleAfterGold(buttonID);
                case GameState.WATERFALL:
                    return HandleWaterfall(buttonID);
                case GameState.WATERFALLGOLD:
                    return HandleWaterfallGold(buttonID);
                case GameState.WATERFALLAFTERGOLD:
                    return HandleWaterfallAfterGold(buttonID);
                case GameState.WATERFALLSWIM:
                    return HandleWaterfallSwim(buttonID);
                case GameState.BAR:
                    return HandleBar(buttonID);
                case GameState.BARDRINK1:
                    return HandleBarDrink1(buttonID);
                case GameState.BARDRINK5:
                    return HandleBarDrink5(buttonID);
                case GameState.BARAFTERSHIFT:
                    return HandleBarAfterShift(buttonID);
                case GameState.BARAFTERSHIFTDRINK1:
                    return HandleBarAfterShiftDrink1(buttonID);
                case GameState.BARAFTERSHIFTDRINK5:
                    return HandleBarAfterShiftDrink5(buttonID);
                case GameState.INSECTKING:
                    return HandleInsectKing(buttonID);
                case GameState.INSECTKING1:
                    return HandleInsectKing1(buttonID); 
                case GameState.INSECTKING2:
                    return HandleInsectKing2(buttonID);
                case GameState.INSECTKING3:
                    return HandleInsectKing3(buttonID);
                case GameState.INSECTKING4:
                    return HandleInsectKing4(buttonID);
                case GameState.INSECTKING5:
                    return HandleInsectKing5(buttonID);
                case GameState.INSECTKING6:
                    return HandleInsectKing6(buttonID);
                case GameState.INSECTKING7:
                    return HandleInsectKing7(buttonID);
                case GameState.INSECTKING8:
                    return HandleInsectKing8(buttonID);
                case GameState.INSECTKING9:
                    return HandleInsectKing9(buttonID);
                case GameState.INSECTKING10:
                    return HandleInsectKing10(buttonID);
                case GameState.INSECTKING11:
                    return HandleInsectKing11(buttonID);
                case GameState.INSECTKING12:
                    return HandleInsectKing12(buttonID);
                case GameState.MINESAFTER:
                    return HandleMinesAfter(buttonID);
                case GameState.MINESAFTERTRY:
                    return HandleMinesAfter(buttonID);
                case GameState.ENTRANCEAFTERSHIFT:
                    return HandleEntranceAfterShift(buttonID);
                case GameState.ENDING1:
                    return HandleEnding1(buttonID);
                case GameState.ENDING2:
                    return HandleEnding2(buttonID);
                case GameState.ENDING3:
                    return HandleEnding3(buttonID);
            }

            return new Choice("", new List<string>() { });
        }

        private Choice HandleEntrance(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)  
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.ENTRANCETRY); // has to be entrancenoeuqip
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.LOCKER);
                    break;
                case ButtonManager.ButtonID.THIRD:
                    if (DrunkCounter < 5)
                    {
                        _manager.SetCurrentGameState(GameState.BAR);
                    }
                    else if (DrunkCounter == 5)
                    {
                        _manager.SetCurrentGameState(GameState.BARDRINK5);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        
        private Choice HandleEntranceAgain(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.ENTRANCETRY);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.LOCKER);
                    break;
                case ButtonManager.ButtonID.THIRD:
                    if (DrunkCounter < 5)
                    {
                        _manager.SetCurrentGameState(GameState.BAR);
                    }
                    else if (DrunkCounter == 5)
                    {
                        _manager.SetCurrentGameState(GameState.BARDRINK5);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        
        private Choice HandleEntranceBroken(ButtonManager.ButtonID buttonID)
        {
            if (HasEquipment && (HasFixedEquipment == false))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                         _manager.SetCurrentGameState(GameState.ENTRANCETRY);
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.LOCKERHASEQUIP);
                        break;
                    case ButtonManager.ButtonID.THIRD:
                        if (DrunkCounter < 5)
                        {
                            _manager.SetCurrentGameState(GameState.BAR);
                        }
                        else if (DrunkCounter == 5)
                        {
                            _manager.SetCurrentGameState(GameState.BARDRINK5);
                        }
                        break;
                }
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleEntranceTry(ButtonManager.ButtonID buttonID)
        {
            switch(buttonID)
            {
                    case ButtonManager.ButtonID.FIRST:
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        if (HasEquipment)
                        _manager.SetCurrentGameState(GameState.LOCKERHASEQUIP);
                        else
                        _manager.SetCurrentGameState(GameState.LOCKER);
                        break;
                    case ButtonManager.ButtonID.THIRD:
                        if (DrunkCounter < 5)
                        {
                            _manager.SetCurrentGameState(GameState.BAR);
                        }
                        else if (DrunkCounter == 5)
                        {
                            _manager.SetCurrentGameState(GameState.BARDRINK5);
                        }
                        break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleEntranceFixed(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.MINES);
                    break;
                case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.LOCKERHASEQUIP);
                        break;
                case ButtonManager.ButtonID.THIRD:
                    if (DrunkCounter < 5)
                    {
                        _manager.SetCurrentGameState(GameState.BAR);
                    }
                    else if (DrunkCounter == 5)
                    {
                        _manager.SetCurrentGameState(GameState.BARDRINK5);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleLocker(ButtonManager.ButtonID buttonID)
        {
            if (HasEquipment == false && (HasFixedEquipment == false))
            {
                // 1. your locker, 2. entrancenoequip
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.LOCKERGETEQUIP);
                        HasEquipment = true;
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEAGAIN); // has to be entrancenoequip
                        break;
                }
            }
            
            else if (HasEquipment && (HasFixedEquipment == false)) // ich glaub das ist an der falschen stelle
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.LOCKERHASEQUIP); // has to be lockerhasequip
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEBROKEN);
                        break;
                    /*
                    case ButtonManager.ButtonID.THIRD:
                        _manager.SetCurrentGameState(GameState.ENTRANCEBROKEN);
                        break;
                        */
                }
            }

            else if (HasEquipment && (HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.LOCKERHASEQUIP); // has to be lockerhasequip
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEFIXED);
                        break;
                }
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        
        // HandleLockerGetEquip (first: gamestate.blacksmith
        private Choice HandleLockerGetEquip(ButtonManager.ButtonID buttonID)
        {
            if (HasFixedEquipment == false)
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.ENTRANCEBROKEN);
                        break;
                }
            }
            else
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.ENTRANCEFIXED);
                        break;
                }
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleLockerHasEquip(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                if (HasFixedEquipment == false)   
                 _manager.SetCurrentGameState(GameState.ENTRANCEBROKEN);
                 else
                    _manager.SetCurrentGameState(GameState.ENTRANCEFIXED);
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleSmith(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.SMITHFIXED);
                    HasFixedEquipment = true;
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.SMITHTALK);
                    break;
                case ButtonManager.ButtonID.THIRD:
                    if (DrunkCounter < 5)
                    {
                        _manager.SetCurrentGameState(GameState.BAR);
                    }
                    else if (DrunkCounter == 5)
                    {
                        _manager.SetCurrentGameState(GameState.BARDRINK5);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        
        private Choice HandleSmithFixed(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.SMITHTALK);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if (DrunkCounter < 5)
                    {
                        _manager.SetCurrentGameState(GameState.BAR);
                    }
                    else if (DrunkCounter == 5)
                    {
                        _manager.SetCurrentGameState(GameState.BARDRINK5);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleSmithNoEquip(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.SMITHTALK);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if (DrunkCounter <= 5)
                    {
                        _manager.SetCurrentGameState(GameState.BAR);
                    }
                    else if (DrunkCounter > 5)
                    {
                        _manager.SetCurrentGameState(GameState.BARDRINK5);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleSmithHasFixed(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.SMITHTALK);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if (DrunkCounter < 5)
                    {
                        _manager.SetCurrentGameState(GameState.BAR);
                    }
                    else if (DrunkCounter == 5)
                    {
                        _manager.SetCurrentGameState(GameState.BARDRINK5);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleSmithTalk(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    if (DrunkCounter < 5)
                    {
                        _manager.SetCurrentGameState(GameState.BAR);
                    }
                    else if (DrunkCounter == 5)
                    {
                        _manager.SetCurrentGameState(GameState.BARDRINK5);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleMines(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    if (!GoldJungle)
                    {
                        _manager.SetCurrentGameState(GameState.JUNGLE);
                    }
                    else if (GoldJungle)
                    {
                        _manager.SetCurrentGameState(GameState.JUNGLEAFTERGOLD);
                    }
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if (!HasDynamite)
                    {
                        _manager.SetCurrentGameState(GameState.BLOCKED_PATH);
                    }
                    else if (HasDynamite)
                    {
                        _manager.SetCurrentGameState(GameState.BLOCKED_PATHUSETNT);
                    }
                    break;
                case ButtonManager.ButtonID.THIRD:
                    if (!GoldWaterfall)
                    {
                        _manager.SetCurrentGameState(GameState.WATERFALL);
                    }
                    else if (GoldWaterfall)
                    {
                        _manager.SetCurrentGameState(GameState.WATERFALLAFTERGOLD);
                    }

                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        
        private Choice HandleJungle(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID) // hier fehlt noch einiges
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.JUNGLEGOLD);
                    GoldCounter += 1;
                    GoldJungle = true;
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.MINES);
                    if(GoldInsect)
                        _manager.SetCurrentGameState(GameState.MINESAFTER);
                    break;
                case ButtonManager.ButtonID.THIRD:
                    if (!VisitedBlockedPath)
                    {
                        _manager.SetCurrentGameState(GameState.ABANDONED_LAIRNOSEARCH);
                    }
                    else if (HasDynamite)
                    {
                        _manager.SetCurrentGameState(GameState.ABANDONED_LAIRTNT);
                    }
                    else if (VisitedBlockedPath && !HasDynamite)
                    {
                        _manager.SetCurrentGameState(GameState.ABANDONED_LAIR);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleJungleGold(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.MINES);
                    if(GoldInsect)
                        _manager.SetCurrentGameState(GameState.MINESAFTER);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if (HasDynamite)
                    {
                        _manager.SetCurrentGameState(GameState.ABANDONED_LAIRTNT);
                        break;
                    }
                    else if (VisitedBlockedPath && !HasDynamite)
                    {
                        _manager.SetCurrentGameState(GameState.ABANDONED_LAIR);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleJungleAfterGold(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.MINES);
                    if(GoldInsect)
                        _manager.SetCurrentGameState(GameState.MINESAFTER);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if (HasDynamite)
                    {
                        _manager.SetCurrentGameState(GameState.ABANDONED_LAIRTNT);
                        break;
                    }
                    else if (VisitedBlockedPath && !HasDynamite)
                    {
                        _manager.SetCurrentGameState(GameState.ABANDONED_LAIR);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        
        private Choice HandleWaterfall(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.WATERFALLSWIM);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.WATERFALLGOLD);
                    GoldCounter += 1;
                    GoldWaterfall = true;
                    break;
                case ButtonManager.ButtonID.THIRD:
                    _manager.SetCurrentGameState(GameState.MINES);
                    if(GoldInsect)
                        _manager.SetCurrentGameState(GameState.MINESAFTER);
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleWaterfallGold(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.MINES);
                    if(GoldInsect)
                        _manager.SetCurrentGameState(GameState.MINESAFTER);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.WATERFALLSWIM);
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleWaterfallAfterGold(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.WATERFALLSWIM);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.MINES);
                    if(GoldInsect)
                        _manager.SetCurrentGameState(GameState.MINESAFTER);
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleWaterfallSwim(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.MINES);
                    if(GoldInsect)
                        _manager.SetCurrentGameState(GameState.MINESAFTER);
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleAbandonedLair(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        if (VisitedBlockedPath)
                        {
                            _manager.SetCurrentGameState(GameState.ABANDONED_LAIRSEARCHFIND);
                            HasDynamite = true;
                        }
                        else
                        {
                            _manager.SetCurrentGameState(GameState.ABANDONED_LAIRNOSEARCH);
                        }

                        break;
                    case ButtonManager.ButtonID.SECOND:
                        if (!GoldJungle)
                        {
                            _manager.SetCurrentGameState(GameState.JUNGLE);
                        }
                        else if (GoldJungle)
                        {
                            _manager.SetCurrentGameState(GameState.JUNGLEAFTERGOLD);
                        }
                        break;
                }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleAbandonedLairNoSearch(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        if (!GoldJungle)
                        {
                            _manager.SetCurrentGameState(GameState.JUNGLE);
                        }
                        else if (GoldJungle)
                        {
                            _manager.SetCurrentGameState(GameState.JUNGLEAFTERGOLD);
                        }
                        break;
                }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleAbandonedLairTNT(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.ABANDONED_LAIRNOSEARCH);
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        if (!GoldJungle)
                        {
                            _manager.SetCurrentGameState(GameState.JUNGLE);
                        }
                        else if (GoldJungle)
                        {
                            _manager.SetCurrentGameState(GameState.JUNGLEAFTERGOLD);
                        }
                        break;
                }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleAbandonedLairSearchFind(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    if (!GoldJungle)
                    {
                        _manager.SetCurrentGameState(GameState.JUNGLE);
                    }
                    else if (GoldJungle)
                    {
                        _manager.SetCurrentGameState(GameState.JUNGLEAFTERGOLD);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleBlockedPath(ButtonManager.ButtonID buttonID)
        {
            
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.MINES);
                        VisitedBlockedPath = true;
                        break;
                }
                return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleBlockedPathUseTNT(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.BLOCKED_PATHTNT);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.MINES);
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleBlockedPathTNT(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING);
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleBar(ButtonManager.ButtonID buttonID)
        {
            if (!HasEquipment && (!HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARDRINK1);
                        DrunkCounter += 1;
                        if (DrunkCounter == 5)
                             _manager.SetCurrentGameState(GameState.BARDRINK5);
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.SMITHNOEQUIP);
                        break;
                    case ButtonManager.ButtonID.THIRD:
                        _manager.SetCurrentGameState(GameState.ENTRANCEAGAIN); // has to be entrancenoequip
                        break;
                }
            }

            else if (HasEquipment && (!HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARDRINK1);
                        DrunkCounter += 1;
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.SMITH);
                        break;
                    case ButtonManager.ButtonID.THIRD:
                        _manager.SetCurrentGameState(GameState.ENTRANCEBROKEN);
                        break;
                }
            }

            else if (HasEquipment && (HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARDRINK1);
                        DrunkCounter += 1;
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.SMITHHASFIXED);
                        break;
                    case ButtonManager.ButtonID.THIRD:
                        _manager.SetCurrentGameState(GameState.ENTRANCEFIXED);
                        break;
                }
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        
        private Choice HandleBarDrink1(ButtonManager.ButtonID buttonID)
        {
            if (!HasEquipment && (!HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARDRINK1);
                        DrunkCounter += 1;
                        if (DrunkCounter == 5)
                        {
                            _manager.SetCurrentGameState(GameState.BARDRINK5);
                        }
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.SMITHNOEQUIP);
                        break;
                    case ButtonManager.ButtonID.THIRD:
                        _manager.SetCurrentGameState(GameState.ENTRANCEAGAIN); // has to be noequip
                        break;
                }
            }
            
            else if (HasEquipment && (!HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARDRINK1);
                        DrunkCounter += 1;
                        if (DrunkCounter == 5)
                        {
                            _manager.SetCurrentGameState(GameState.BARDRINK5);
                        }
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.SMITH);
                        break;
                    case ButtonManager.ButtonID.THIRD:
                        _manager.SetCurrentGameState(GameState.ENTRANCEBROKEN);
                        break;
                }
            }
            else
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARDRINK1);
                        DrunkCounter += 1;
                        if (DrunkCounter == 5)
                        {
                            _manager.SetCurrentGameState(GameState.BARDRINK5);
                        }
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.SMITHHASFIXED);
                        break;
                    case ButtonManager.ButtonID.THIRD:
                        _manager.SetCurrentGameState(GameState.ENTRANCEFIXED);
                        break;
                }
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleBarDrink5(ButtonManager.ButtonID buttonID)
        {
            if (!HasEquipment && (!HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.SMITHNOEQUIP);
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEAGAIN); // has to be noequip
                        break;
                }
            }

            else if (HasEquipment && (!HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.SMITH);
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEBROKEN);
                        break;
                }
            }

            else
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.SMITHHASFIXED);
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEFIXED);
                        break;
                }
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleBarAfterShift(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.BARAFTERSHIFTDRINK1);
                    DrunkCounter += 1;
                    Drinks2 += 1;
                    if (Drinks2 == 5)
                             _manager.SetCurrentGameState(GameState.BARDRINK5);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.ENTRANCEAFTERSHIFT); // has to be entrancenoequip
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }

        private Choice HandleBarAfterShiftDrink1(ButtonManager.ButtonID buttonID)
        {
            if (!HasEquipment && (!HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARAFTERSHIFTDRINK1);
                        DrunkCounter += 1;
                        Drinks2 += 1;
                        if (Drinks2 == 5 )
                        {
                            _manager.SetCurrentGameState(GameState.BARAFTERSHIFTDRINK5);
                        }
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEAFTERSHIFT); // has to be entrancenoequip
                        break;
                }
            }

            else if (HasEquipment && (!HasFixedEquipment))
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARAFTERSHIFTDRINK1);
                        DrunkCounter += 1;
                        Drinks2 += 1;
                        if (Drinks2 == 5)
                        {
                            _manager.SetCurrentGameState(GameState.BARAFTERSHIFTDRINK5);
                        }
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEBROKEN);
                        break;
                }
            }

            else
            {
                switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.BARAFTERSHIFTDRINK1);
                        DrunkCounter += 1;
                        Drinks2 += 1;
                        if (Drinks2 == 5)
                        {
                            _manager.SetCurrentGameState(GameState.BARAFTERSHIFTDRINK5);
                        }
                        break;
                    case ButtonManager.ButtonID.SECOND:
                        _manager.SetCurrentGameState(GameState.ENTRANCEFIXED);
                        break;
                }
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleBarAfterShiftDrink5(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
                {
                    case ButtonManager.ButtonID.FIRST:
                        _manager.SetCurrentGameState(GameState.ENTRANCEAFTERSHIFT);
                        break;
                }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
         private Choice HandleInsectKing(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING1);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing1(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING2);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing2(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING3);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing3(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING4);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing4(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING5);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing5(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING6);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing6(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING11);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    _manager.SetCurrentGameState(GameState.INSECTKING7);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing7(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING8);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing8(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING9);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing9(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    GoldInsect = true;
                    GoldCounter += 1;
                    _manager.SetCurrentGameState(GameState.INSECTKING10);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing10(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.MINESAFTER);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing11(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.INSECTKING12);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleInsectKing12(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    _manager.SetCurrentGameState(GameState.ENDING1);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleEntranceAfterShift(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    if(DrunkCounter == 10)
                    {
                        _manager.SetCurrentGameState(GameState.ENDING3);
                    }
                    else
                        _manager.SetCurrentGameState(GameState.ENDING2);
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if(Drinks2 < 5)
                        _manager.SetCurrentGameState(GameState.BARAFTERSHIFT);
                    else 
                        _manager.SetCurrentGameState(GameState.BARAFTERSHIFTDRINK5);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
         private Choice HandleMinesAfter(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    if (!GoldJungle)
                    {
                        _manager.SetCurrentGameState(GameState.JUNGLE);
                    }
                    else if (GoldJungle)
                    {
                        _manager.SetCurrentGameState(GameState.JUNGLEAFTERGOLD);
                    }
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if (GoldCounter == 3)
                        _manager.SetCurrentGameState(GameState.ENTRANCEAFTERSHIFT);
                    else
                        _manager.SetCurrentGameState(GameState.MINESAFTERTRY);
                    break;
                case ButtonManager.ButtonID.THIRD:
                    if (!GoldWaterfall)
                    {
                        _manager.SetCurrentGameState(GameState.WATERFALL);
                    }
                    else if (GoldWaterfall)
                    {
                        _manager.SetCurrentGameState(GameState.WATERFALLAFTERGOLD);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
            private Choice HandleMinesAfterTry(ButtonManager.ButtonID buttonID)
            {
            switch (buttonID)
            {
                case ButtonManager.ButtonID.FIRST:
                    if (!GoldJungle)
                    {
                        _manager.SetCurrentGameState(GameState.JUNGLE);
                    }
                    else if (GoldJungle)
                    {
                        _manager.SetCurrentGameState(GameState.JUNGLEAFTERGOLD);
                    }
                    break;
                case ButtonManager.ButtonID.SECOND:
                    if (GoldCounter == 3)
                        _manager.SetCurrentGameState(GameState.ENTRANCEAFTERSHIFT);
                    break;
                case ButtonManager.ButtonID.THIRD:
                    if (!GoldWaterfall)
                    {
                        _manager.SetCurrentGameState(GameState.WATERFALL);
                    }
                    else if (GoldWaterfall)
                    {
                        _manager.SetCurrentGameState(GameState.WATERFALLAFTERGOLD);
                    }
                    break;
            }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleEnding1(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    SceneManager.LoadScene(0);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleEnding2(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    SceneManager.LoadScene(0);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        private Choice HandleEnding3(ButtonManager.ButtonID buttonID)
        {
             switch (buttonID)
             {
                case ButtonManager.ButtonID.FIRST:
                    SceneManager.LoadScene(0);
                    break;
             }
            return _manager.GetGameStory().DisplayState(_manager.GetCurrentGameState());
        }
        /*
        private Choice HandleBarAfterShiftDrink5(ButtonManager.ButtonID buttonID)
        {
            switch (buttonID)
            {
                
            }
        }
        */
        // getter
        public int GetDrunkCounter()
        {
            return DrunkCounter;
        }

        public int GetGoldCounter()
        {
            return GoldCounter;
        }

        public bool GetHasEquipment()
        {
            return HasEquipment;
        }

        public bool GetHasFixedEquipment()
        {
            return HasFixedEquipment;
        }

        public bool GetHasDynamite()
        {
            return HasDynamite;
        }

        public bool GetVisitedBlockedPath()
        {
            return VisitedBlockedPath;
        }
        // setter

        public void SetHasEquipment(bool newValue)
        {
            HasEquipment = newValue;
        }

        public void SetHasFixedEquipment(bool newValue)
        {
            HasFixedEquipment = newValue;
        }

        public void SetHasDynamite(bool newValue)
        {
            HasDynamite = newValue;
        }

        public void SetImage(BackgroundImage image)
        {
            _manager.SetBackgroundImage(image);
        }

        public void ImageSelector()
        {
            switch (_manager.GetCurrentGameState())
            {
                case GameState.ENTRANCE:
                    SetImage(BackgroundImage.CAVE_ENTRANCE);
                    break;
                case GameState.ENTRANCEAFTERSHIFT:
                    SetImage(BackgroundImage.CAVE_ENTRANCE);
                    break;
                case GameState.ENTRANCEAGAIN:
                    SetImage(BackgroundImage.CAVE_ENTRANCE);
                    break;
                case GameState.ENTRANCEBROKEN:
                    SetImage(BackgroundImage.CAVE_ENTRANCE);
                    break;
                case GameState.ENTRANCEFIXED:
                    SetImage(BackgroundImage.CAVE_ENTRANCE);
                    break;
                case GameState.ENTRANCETRY:
                    SetImage(BackgroundImage.CAVE_ENTRANCE);
                    break;
                case GameState.LOCKER:
                    SetImage(BackgroundImage.LOCKER_ROOM);
                    break;
                case GameState.LOCKERGETEQUIP:
                    SetImage(BackgroundImage.LOCKER_ROOM);
                    break;
                case GameState.LOCKERHASEQUIP:
                    SetImage(BackgroundImage.LOCKER_ROOM);
                    break;
                case GameState.SMITH:
                    SetImage(BackgroundImage.BLACKSMITH);
                    break;
                case GameState.SMITHASEQUIP:
                    SetImage(BackgroundImage.BLACKSMITH);
                    break;
                case GameState.SMITHFIXED:
                    SetImage(BackgroundImage.BLACKSMITH);
                    break;
                case GameState.SMITHHASFIXED:
                    SetImage(BackgroundImage.BLACKSMITH);
                    break;
                case GameState.SMITHNOEQUIP:
                    SetImage(BackgroundImage.BLACKSMITH);
                    break;
                case GameState.SMITHTALK:
                    SetImage(BackgroundImage.BLACKSMITH);
                    break;
                case GameState.MINES:
                    SetImage(BackgroundImage.CAVE);
                    break;
                case GameState.MINESAFTER:
                    SetImage(BackgroundImage.CAVE);
                    break;
                case GameState.ABANDONED_LAIR:
                    SetImage(BackgroundImage.STORAGE_ROOM);
                    break;
                case GameState.ABANDONED_LAIRNOSEARCH:
                    SetImage(BackgroundImage.STORAGE_ROOM);
                    break;
                case GameState.ABANDONED_LAIRSEARCHFIND:
                    SetImage(BackgroundImage.STORAGE_ROOM);
                    break;
                case GameState.ABANDONED_LAIRTNT:
                    SetImage(BackgroundImage.STORAGE_ROOM);
                    break;
                case GameState.BLOCKED_PATH:
                    SetImage(BackgroundImage.BLOCKED_PATH);
                    break;
                case GameState.BLOCKED_PATHTNT:
                    SetImage(BackgroundImage.BLOCKED_PATH);
                    break;
                case GameState.BLOCKED_PATHUSETNT:
                    SetImage(BackgroundImage.BLOCKED_PATH);
                    break;
                case GameState.JUNGLE:
                    SetImage(BackgroundImage.JUNGLE);
                    break;
                case GameState.JUNGLEAFTERGOLD:
                    SetImage(BackgroundImage.JUNGLE);
                    break;
                case GameState.JUNGLEGOLD:
                    SetImage(BackgroundImage.JUNGLE);
                    break;
                case GameState.WATERFALL:
                    SetImage(BackgroundImage.WATERFALL);
                    break;
                case GameState.WATERFALLAFTERGOLD:
                    SetImage(BackgroundImage.WATERFALL);
                    break;
                case GameState.WATERFALLGOLD:
                    SetImage(BackgroundImage.WATERFALL);
                    break;
                case GameState.WATERFALLSWIM:
                    SetImage(BackgroundImage.WATERFALL);
                    break;
                case GameState.BAR:
                    SetImage(BackgroundImage.BAR);
                    break;
                case GameState.BARAFTERSHIFT:
                    SetImage(BackgroundImage.BAR);
                    break;
                case GameState.BARAFTERSHIFTDRINK1:
                    SetImage(BackgroundImage.BAR);
                    break;
                case GameState.BARAFTERSHIFTDRINK5:
                    SetImage(BackgroundImage.BAR);
                    break;
                case GameState.BARDRINK1:
                    SetImage(BackgroundImage.BAR);
                    break;
                case GameState.BARDRINK5:
                    SetImage(BackgroundImage.BAR);
                    break;
                case GameState.INSECTKING:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING1:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING2:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING3:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING4:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING5:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING6:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING7:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING8:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING9:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING10:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING11:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.INSECTKING12:
                    SetImage(BackgroundImage.THRONE_ROOM);
                    break;
                case GameState.ENDING1:
                    SetImage(BackgroundImage.ENDING);
                    break;
                case GameState.ENDING2:
                    SetImage(BackgroundImage.ENDING);
                    break;
                case GameState.ENDING3:
                    SetImage(BackgroundImage.ENDING);
                    break;
            }
        }
    }
}